city

# XMLRésuméLibrary: User Guide

citation | Element Reference | clearance

## Name

city — The name of a city

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `city` element contains a the name of a single city or other similar municipality.

### Parents

`city` may be contained in these elements: `address`, `location`

### Attributes

`id`

  A string used to uniquely identify a city. The city may then be referred to by this identifier.

## See Also

`county`, `prefecture`, `suburb`, `ward`.

## Examples

    <address>
      <street>3400 N. 5230 S.</street>
      <city>Salt Lake City</city>
      <state>UT</state>
      <zip>84352</zip>
    </address>

citation | Element Reference | clearance